/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.datacenter.services.relation_calc

import RelBuilding
import com.persagy.base.extensions.toJson
import com.persagy.database.SFilter
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.Opt
import com.persagy.server.datacenter.datacenter.dao.mappers.SchemeMapper
import com.persagy.server.datacenter.datacenter.models.entities.dictnew.DefClass
import com.persagy.server.datacenter.datacenter.models.entities.rel.REq2Sp
import com.persagy.server.datacenter.models.entities.graphtype.RelationTypeProject
import com.persagy.server.datacenter.datacenter.models.entities.graphtype.rel.RelZoneSpace
import com.persagy.server.datacenter.datacenter.models.entities.rel.REq2Sy
import com.persagy.server.datacenter.models.entities.graphtype.rel.*
import com.persagy.server.datacenter.models.entities.graphtype.rel.control.*
import com.persagy.server.datacenter.models.entities.graphtype.rel.drainage.*
import com.persagy.server.datacenter.models.entities.graphtype.rel.electricity.*
import com.persagy.server.datacenter.models.entities.graphtype.rel.hvac.*
import com.persagy.server.datacenter.models.entities.rel.*
import com.persagy.server.datacenter.models.requests.ManualRelationCalcDel
import com.persagy.server.datacenter.datacenter.models.requests.ManualRelationCalcRequest
import com.persagy.server.datacenter.models.entities.graphtype.rel.RelFloor
import com.persagy.server.datacenter.services.objects.BuildingService
import com.persagy.server.datacenter.services.objects.EquipmentService
import com.persagy.server.datacenter.wanda.obj.Equipment
import com.persagy.server.datacenter.wanda.rel.*
import com.persagy.server.datacenter.wanda.response.ManualRelationCalcResponse
import com.persagy.server.jms.RabbitMqService
import com.persagy.server.services.objects.*
import com.persagy.server.services.rel.*
import com.persagy.service.SObjectService
import com.persagy.service.SPageContext
import com.persagy.service.models.SCascadeQuery
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.utils.SSpringContextUtil
import org.slf4j.LoggerFactory
import org.springframework.stereotype.Service
import java.text.SimpleDateFormat
import java.util.*
import kotlin.collections.ArrayList

/**
 * 手动计算
 *
 * @author 张维新
 */
@Service
open class ManualRelationCalcService {
    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(ManualRelationCalcService::class.java)
        /** RabbitMQ消息对象 */
        val rabbitMqService by lazy {
            SSpringContextUtil.getBean(RabbitMqService::class.java) as RabbitMqService
        }

        val schemeMapper by lazy {
            SSpringContextUtil.getBean(SchemeMapper::class.java) as SchemeMapper
        }

    } // Companion object
//    /** 资产服务 */
//    private val relPropertyService = SObjectService(SMybatisDao(RelProperty::class.java))


    /** 设备建筑 设备 */
    private val relEquipBuildingService = SObjectService(SMybatisDao(RelEq2BdEquip::class.java))
    /** 设备级联楼层 */
    private val relEquipFloorService = SObjectService(SMybatisDao(RelEq2FlEquip::class.java))
    /** 关系建筑 */
    private val relBuildingService = SObjectService(SMybatisDao(RelBuilding::class.java))
    /** 关系楼层 */
    private val relFloorService = SObjectService(SMybatisDao(RelFloor::class.java))
    /** 建筑和空间的关系-建筑 */
    private val rBd2SpBuilidingService = SObjectService(SMybatisDao(RBd2SpBuiliding::class.java))
    /** 空间 */
    private val spaceBaseZoneService = SObjectService(SMybatisDao(SpaceBaseZone::class.java))




    /** 资产所在的空间 *******************************************************/
    private val rPeInSpBaseService = SObjectService(SMybatisDao(RPe2Sp::class.java))
    /** 设备服务于竖井 */
    private val rEq2ShService = SObjectService(SMybatisDao(REq2Sh::class.java))
    /** 设备服务于楼层 */
    private val rEq2FlService = SObjectService(SMybatisDao(REq2Fl::class.java))
    /** 系统和空间关系 */
    private val rSy2SpService = SObjectService(SMybatisDao(RSy2Sp::class.java))
    /** 系统和竖井关系 */
    private val rSy2ShService = SObjectService(SMybatisDao(RSy2Sh::class.java))
    /** 系统和楼层关系 */
    private val rSy2FlService = SObjectService(SMybatisDao(RSy2Fl::class.java))
    /** 系统和建筑关系 */
    private val rSy2BdService = SObjectService(SMybatisDao(RSy2Bd::class.java))
    /** 空间和空间的关系 */
    private val rSp2SpService = SObjectService(SMybatisDao(RSp2Sp::class.java))
    /** 设备和设备关系 */
    private val rEq2EqService = SObjectService(SMybatisDao(REq2Eq::class.java))
    /** 设备和系统关系 */
    private val rEq2SyService = SObjectService(SMybatisDao(REq2Sy::class.java))
    /** 设备和空间关系 */
    private val rEq2SpService = SObjectService(SMybatisDao(REq2Sp::class.java))

    /** 空间 */
    private val relZoneSpaceService = SObjectService(SMybatisDao(RelZoneSpace::class.java))
    /** 类型查询 */
    private val dClassDefService = SObjectService(SMybatisDao(DefClass::class.java))
    /** 资产所在的竖井 */
    private val rPeInShService = SObjectService(SMybatisDao(RPeInSh::class.java))
    /** 资产和竖井的资产实例 */
    private val relPropertyShaftService = SObjectService(SMybatisDao(RelPropertyShaft::class.java))
    /** 竖井 */
    private val relShaftService = SObjectService(SMybatisDao(RelShaft::class.java))
    /** 设备和竖井的设备 */
    private val relEquipmentShaftService = SObjectService(SMybatisDao(RelEquipmentShaft::class.java))
    /** 设备和楼层的设备 */
    private val  relEquipmentFloorService = SObjectService(SMybatisDao(RelEquipmentFloor::class.java))
    /** 设备服务于建筑 设备 */
    private val relEquipmentBuildingService = SObjectService(SMybatisDao(RelEquipmentBuilding::class.java))
    /** 系统服务于业务空间 */
    private val relGeneralSystemService = SObjectService(SMybatisDao(RelGeneralSystem::class.java))
    /** 系统服务于竖井 */
    private val relGeneralSystemShaftService = SObjectService(SMybatisDao(RelGeneralSystemShaft::class.java))
    /** 系统服务于楼层 */
    private val relGeneralSystemFloorService = SObjectService(SMybatisDao(RelGeneralSystemFloor::class.java))
    /** 系统服务于建筑 */
    private val relGeneralSystemBuildingService = SObjectService(SMybatisDao(RelGeneralSystemBuilding::class.java))


    /**
     * 查询关系数据
     */
//    fun query(manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {
//
//        try {
//            /** 项目id */
//            val projectId = SPageContext.getHeader("ProjectId")
//            val list = ArrayList<SFilter>()
//            list.add(SFilter.eq("projectId",projectId!!))
//            /** 模糊查询 */
//            if(!manualRelationCalcRequest.vague.isNullOrEmpty()){
//                list.add( SFilter.or(SFilter.contain("id",manualRelationCalcRequest.vague!!),SFilter.contain("name",manualRelationCalcRequest.vague!!)
//                    ,SFilter.contain("localName",manualRelationCalcRequest.vague!!),SFilter.contain("localId",manualRelationCalcRequest.vague!!)))
//            }
//
//            val sQueryRequest = SQueryRequest()
//
//            if(manualRelationCalcRequest.pageNumber>0&&manualRelationCalcRequest.pageSize>0){
//                SQueryRequest.maxRow = 400000
//                sQueryRequest.pageSize= manualRelationCalcRequest.pageSize
//                sQueryRequest.pageNumber = manualRelationCalcRequest.pageNumber
//            }else{
//                /** 控制条数 */
//                SQueryRequest.maxRow = 100000
//                sQueryRequest.pageSize= 100000
//            }
//            val sCascadeQueryList = ArrayList<SCascadeQuery>()
//            /** 级联资产 */
//            val sCascadeQuery = SCascadeQuery()
//            sCascadeQuery.name = "objectInfo"
//            if (!manualRelationCalcRequest.category.isNullOrEmpty()) {
//                sCascadeQuery.filters = "zoneType = '${manualRelationCalcRequest.category}'"
//            }
//            sCascadeQueryList.add(sCascadeQuery)
//            sQueryRequest.cascade = sCascadeQueryList
//
//
//            if (manualRelationCalcRequest.graphicType == "ArchSubset" && manualRelationCalcRequest.relType == "Bd2Sp") {
//
//            } else if (manualRelationCalcRequest.graphicType == "ArchSubset" && manualRelationCalcRequest.relType == "Fl2Sp") {
//
//            } else if (manualRelationCalcRequest.graphicType == "MechInArch" && manualRelationCalcRequest.relType == "Eq2Bd") {
//
//            } else if (manualRelationCalcRequest.graphicType == "MechInArch" && manualRelationCalcRequest.relType == "Eq2Fl") {
//
//            } else if (manualRelationCalcRequest.graphicType == "ArchForArch" && manualRelationCalcRequest.relType == "Sp2Sp") {
//
//            } else if (manualRelationCalcRequest.graphicType == "MechSubset" && manualRelationCalcRequest.relType == "Sy2Eq") {
//
//            } else if (manualRelationCalcRequest.graphicType == "MechInArch" && manualRelationCalcRequest.relType == "Eq2Sp") {
//
//            } else if (manualRelationCalcRequest.graphicType == "MechForArch" && manualRelationCalcRequest.relType == "Eq2Sp") {
//
//            }
//
//            if (manualRelationCalcRequest.relType == "pe2sp"){
//                /** 资产所在业务空间 */
//                return queryPe2Sp(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "pe2sh"){
//                /** 资产所在竖井 */
//                return queryPe2Sh(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "eq2sh_for"){
//                /** 设备服务于竖井 */
//                return queryEqForSh(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "eq2fl_for"){
//                /** 设备服务于楼层 */
//                return queryEqForFl(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "eq2bd_for"){
//                /** 设备服务于建筑 */
//                return queryEqForBd(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "sy2sp_for"){
//                /** 系统服务于业务空间 */
//                return querySyForSp(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if(manualRelationCalcRequest.relType == "sy2sh_for"){
//                /** 系统服务于竖井 */
//                return querySyForSh(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "sy2fl_for"){
//                /** 系统服务于楼层 */
//                return querySyForFl(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "sy2bd_for"){
//                /** 系统服务于建筑 */
//                return querySyForBd(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "sp2sp_ConvectionNetwork_1"||manualRelationCalcRequest.relType == "sp2sp_ConvectionNetwork_2"||manualRelationCalcRequest.relType == "sp2sp_ConvectionNetwork_3"
//                ||manualRelationCalcRequest.relType == "sp2sp_SpaceNeighborhood_5"||manualRelationCalcRequest.relType == "sp2sp_SpaceNeighborhood_2"||manualRelationCalcRequest.relType == "sp2sp_SpaceNeighborhood_4"
//                ||manualRelationCalcRequest.relType == "sp2sp_TrafficNetwork_3"||manualRelationCalcRequest.relType == "sp2sp_TrafficNetwork_2"||manualRelationCalcRequest.relType == "sp2sp_RadiationNetwork_1"
//                ||manualRelationCalcRequest.relType == "sp2sp_RadiationNetwork_2"||manualRelationCalcRequest.relType == "sp2sp_SpaceNeighborhood_1"||manualRelationCalcRequest.relType == "sp2sp_TrafficNetwork_1"
//                ||manualRelationCalcRequest.relType == "sp2sp_SpaceNeighborhood_3" ){
//                /** 空间 空气自然对流 */
//                return querySpAirConvection(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "eq2eq_LUDistribution_1"||manualRelationCalcRequest.relType == "eq2eq_LUDistribution_2"||manualRelationCalcRequest.relType == "eq2eq_HUDistribution_1"
//                ||manualRelationCalcRequest.relType == "eq2eq_HUDistribution_2"||manualRelationCalcRequest.relType == "eq2eq_EquipPower_1"||manualRelationCalcRequest.relType == "eq2eq_EquipPower_2"
//                ||manualRelationCalcRequest.relType == "eq2eq_EquipPower_3"||manualRelationCalcRequest.relType == "eq2eq_EquipPower_4"){
//                /** 系统备用电源 */ /** 强电类 */
//                return queryElectricity(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            } else if (manualRelationCalcRequest.relType == "eq2eq_ACAirNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_ACAirNetwork_3"||manualRelationCalcRequest.relType == "eq2eq_ACAirNetwork_2"
//                ||manualRelationCalcRequest.relType == "eq2eq_ChillWaterLoop_4"|| manualRelationCalcRequest.relType == "eq2eq_ChillWaterLoop_1"||manualRelationCalcRequest.relType == "eq2eq_ChillWaterLoop_3"
//                || manualRelationCalcRequest.relType == "eq2eq_ChillWaterLoop_2"||manualRelationCalcRequest.relType == "eq2eq_CondWaterNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_CoolingWaterLoop_4"
//                ||manualRelationCalcRequest.relType == "eq2eq_CoolingWaterLoop_1"||manualRelationCalcRequest.relType == "eq2eq_CoolingWaterLoop_3"||manualRelationCalcRequest.relType == "eq2eq_CoolingWaterLoop_2"
//                ||manualRelationCalcRequest.relType == "eq2eqFreshAirNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_HeatWaterLoop_4"||manualRelationCalcRequest.relType == "eq2eq_HeatWaterLoop_1"
//                ||manualRelationCalcRequest.relType == "eq2eq_HeatWaterLoop_3"||manualRelationCalcRequest.relType == "eq2eq_HeatWaterLoop_2"||manualRelationCalcRequest.relType == "eq2eq_VentNetwork_1"
//                ||manualRelationCalcRequest.relType == "eq2eq_VentNetwork_3"||manualRelationCalcRequest.relType == "eq2eq_VentNetwork_2"||manualRelationCalcRequest.relType == "eq2eq_VRFNetwork_1"){
//                /** 暖通空调类 */
//                return hvac(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "eq2eq_SupplyWaterNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_SupplyWaterNetwork_2"||manualRelationCalcRequest.relType == "eq2eq_DrainingWaterNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_DrainingWaterNetwork_2"
//                ||manualRelationCalcRequest.relType == "eq2eq_DrinkingWaterNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_DrinkingWaterNetwork_2"||manualRelationCalcRequest.relType == "eq2eq_DHWNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_DHWNetwork_2"
//                ||manualRelationCalcRequest.relType == "eq2eq_GasNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_GasNetwork_2"||manualRelationCalcRequest.relType == "eq2eq_FireWaterNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_FireWaterNetwork_2"
//                ||manualRelationCalcRequest.relType == "eq2eq_FireVentNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_RecycleWaterNetwork_1" ||manualRelationCalcRequest.relType == "eq2eq_RecycleWaterNetwork_2"){
//                /** 给排水类 和 消防类 */
//                return drainage(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "eq2eq_SensorNetwork_1"||manualRelationCalcRequest.relType == "eq2eq_ControlRelation_1"
//                ||manualRelationCalcRequest.relType == "eq2eq_SensorRelationship_ss2eq"||manualRelationCalcRequest.relType == "eq2eq_ValveRelationship_vv2eq"||manualRelationCalcRequest.relType =="eq2eq_ControlEquipNetwork"){
//                /** 测控类 */
//                return control(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "eq2eq_ControlRelation_2"||manualRelationCalcRequest.relType == "eq2sy_SensorRelationship_ss2sy"
//                ||manualRelationCalcRequest.relType == "eq2sy_ValveRelationship_vv2sy"){
//                /** 测控类 */
//                return controlSy(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if(manualRelationCalcRequest.relType == "eq2sp_SensorRelationship_ss2sp"){
//                return ss2sps(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else if (manualRelationCalcRequest.relType == "eq2sp_x"){
//                return  eq2spsOther(projectId,list,sQueryRequest,manualRelationCalcRequest)
//            }else{
//                /** 暂无数据 */
//                val manualRelationCalcResponse = ManualRelationCalcResponse()
//                manualRelationCalcResponse.result = SResponseType.success
//                manualRelationCalcResponse.content = ArrayList<RelProperty>()
//                return manualRelationCalcResponse
//            }
//            /** 暂无数据 */
//            val manualRelationCalcResponse = ManualRelationCalcResponse()
//            manualRelationCalcResponse.result = SResponseType.success
//            manualRelationCalcResponse.content = ArrayList<RelProperty>()
//            return manualRelationCalcResponse
//        } catch (e: Exception) {
//            e.printStackTrace()
//            val manualRelationCalcResponse = ManualRelationCalcResponse()
//            manualRelationCalcResponse.result = SResponseType.failure
//            manualRelationCalcResponse.content = ArrayList<RelProperty>()
//            manualRelationCalcResponse.message = e.message.toString()
//            return manualRelationCalcResponse
//        }
//    }


    fun  queryRel(manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {


        if (manualRelationCalcRequest.graphicType == "ArchSubset" && manualRelationCalcRequest.relType == "Bd2Sp") {
            return queryBd2Sp(manualRelationCalcRequest)
            } else if (manualRelationCalcRequest.graphicType == "ArchSubset" && manualRelationCalcRequest.relType == "Fl2Sp") {
            return ManualRelationCalcResponse()
            } else if (manualRelationCalcRequest.graphicType == "MechInArch" && manualRelationCalcRequest.relType == "Eq2Bd") {
                return  queryEq2Bd(manualRelationCalcRequest)
            } else if (manualRelationCalcRequest.graphicType == "MechInArch" && manualRelationCalcRequest.relType == "Eq2Fl") {
                return queryEq2Fl(manualRelationCalcRequest)
            } else if (manualRelationCalcRequest.graphicType == "ArchForArch" && manualRelationCalcRequest.relType == "Sp2Sp") {
            return ManualRelationCalcResponse()
            } else if (manualRelationCalcRequest.graphicType == "MechSubset" && manualRelationCalcRequest.relType == "Sy2Eq") {
            return ManualRelationCalcResponse()
            } else if (manualRelationCalcRequest.graphicType == "MechInArch" && manualRelationCalcRequest.relType == "Eq2Sp") {
            return ManualRelationCalcResponse()
            }else if (manualRelationCalcRequest.graphicType == "MechForArch" && manualRelationCalcRequest.relType == "Eq2Sp"){
            return ManualRelationCalcResponse()
            }
        return ManualRelationCalcResponse()

    }

    /**
     * 设备所在建筑查询
     */
    fun queryEq2Bd(manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {
        val sQueryRequest = SQueryRequest()
        if(manualRelationCalcRequest.pageNumber>0&&manualRelationCalcRequest.pageSize>0){
            SQueryRequest.maxRow = 400000
            sQueryRequest.pageSize= manualRelationCalcRequest.pageSize
            sQueryRequest.pageNumber = manualRelationCalcRequest.pageNumber
        }else{
            /** 控制条数 */
            SQueryRequest.maxRow = 100000
            sQueryRequest.pageSize= 100000
        }

        val sCascadeQueryList = ArrayList<SCascadeQuery>()
        /** 级联资产 */
        val sCascadeQuery = SCascadeQuery()
        sCascadeQuery.name = "objectInfo"
        sCascadeQueryList.add(sCascadeQuery)
        sQueryRequest.cascade = sCascadeQueryList

        val manualRelationCalcResponse = ManualRelationCalcResponse()
        manualRelationCalcResponse.direction = "Left"
        val list = ArrayList<SFilter>()
        list.add(SFilter.eq("projectId",Opt.projectId!!))
        if (manualRelationCalcRequest.objectType == "1") {

            list.add(SFilter.not(SFilter.isNull("buildingId")))
            /** 模糊查询 */
            if(!manualRelationCalcRequest.vagueFrom.isNullOrEmpty()){
                list.add( SFilter.or(SFilter.contain("id",manualRelationCalcRequest.vagueFrom!!),SFilter.contain("name",manualRelationCalcRequest.vagueFrom!!)
                        ,SFilter.contain("localName",manualRelationCalcRequest.vagueFrom!!),SFilter.contain("localId",manualRelationCalcRequest.vagueFrom!!)))
            }
            if (!manualRelationCalcRequest.categoryFrom.isNullOrEmpty()) {
                list.add(SFilter.eq("classCode",manualRelationCalcRequest.categoryFrom!!))
            }
            val pageQuery = relEquipBuildingService.pageQuery(sQueryRequest,list)
            manualRelationCalcResponse.content = pageQuery.content
            manualRelationCalcResponse.message = pageQuery.message
            manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
            manualRelationCalcResponse.pageSize = pageQuery.pageSize
            manualRelationCalcResponse.result = pageQuery.result
            manualRelationCalcResponse.total = pageQuery.total

            return manualRelationCalcResponse
        }else if (manualRelationCalcRequest.objectType == "2"){

            if (!manualRelationCalcRequest.vagueFrom.isNullOrEmpty()) {
                val relEquipBuildingList = relEquipBuildingService.select(SFilter.eq("projectId", Opt.projectId!!), SFilter.not(SFilter.isNull("buildingId"))).exec()
                if (relEquipBuildingList.size>0) {

                    val buildingIdList = schemeMapper.buildingId(Opt.projectId!!)
                    val listId = ArrayList<String>()
                    for (buildingId in buildingIdList) {
                        listId.add(buildingId.id!!)
                    }

                    val relBuildinglist = relBuildingService.select(SFilter.inList("id", listId), SFilter.contain("localName", manualRelationCalcRequest.vagueTo!!)).exec()
                    if (relBuildinglist.size>0) {
                        val listIds = ArrayList<String>()
                        for (building in relBuildinglist) {
                            listIds.add(building.id!!)
                        }
                        list.add(SFilter.inList("buildingId",listIds))
                        val pageQuery = relEquipBuildingService.pageQuery(sQueryRequest,list)
                        manualRelationCalcResponse.content = pageQuery.content
                        manualRelationCalcResponse.message = pageQuery.message
                        manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                        manualRelationCalcResponse.pageSize = pageQuery.pageSize
                        manualRelationCalcResponse.result = pageQuery.result
                        manualRelationCalcResponse.total = pageQuery.total

                        return manualRelationCalcResponse
                    }else {
                        manualRelationCalcResponse.content = ArrayList()
                        manualRelationCalcResponse.result = SResponseType.success
                    }
                }else {
                    manualRelationCalcResponse.content = ArrayList()
                    manualRelationCalcResponse.result = SResponseType.success
                }
            }else {
                manualRelationCalcResponse.content = ArrayList()
                manualRelationCalcResponse.result = SResponseType.success
            }

        }else if (manualRelationCalcRequest.objectType == "3") {

            val listType = ArrayList<SFilter>()
            /** 模糊查询 */
            if(!manualRelationCalcRequest.vagueFrom.isNullOrEmpty()){
                listType.add( SFilter.or(SFilter.contain("id",manualRelationCalcRequest.vagueFrom!!),SFilter.contain("name",manualRelationCalcRequest.vagueFrom!!)
                        ,SFilter.contain("localName",manualRelationCalcRequest.vagueFrom!!),SFilter.contain("localId",manualRelationCalcRequest.vagueFrom!!)))
            }
            if (!manualRelationCalcRequest.categoryFrom.isNullOrEmpty()) {
                listType.add(SFilter.eq("classCode",manualRelationCalcRequest.categoryFrom!!))
            }
            listType.add(SFilter.not(SFilter.isNull("buildingId")))
            val relEquipBuildingList = relEquipBuildingService.select(listType).exec()
            if (relEquipBuildingList.size>0) {

                val relBuildinglist = relBuildingService.select(SFilter.eq("projectId", Opt.projectId!!), SFilter.contain("localName", manualRelationCalcRequest.vagueTo!!)).exec()
                if (relBuildinglist.size>0) {
                    val listIds = ArrayList<String>()
                    for (building in relBuildinglist) {
                        listIds.add(building.id!!)
                    }
                    val listEquipIds = ArrayList<String>()
                    for (relEquipBuilding in relEquipBuildingList) {
                        listEquipIds.add(relEquipBuilding.id!!)
                    }

                    list.add(SFilter.inList("buildingId",listIds))
                    list.add(SFilter.inList("id",listEquipIds))
                    val pageQuery = relEquipBuildingService.pageQuery(sQueryRequest,list)
                    manualRelationCalcResponse.content = pageQuery.content
                    manualRelationCalcResponse.message = pageQuery.message
                    manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                    manualRelationCalcResponse.pageSize = pageQuery.pageSize
                    manualRelationCalcResponse.result = pageQuery.result
                    manualRelationCalcResponse.total = pageQuery.total
                    return manualRelationCalcResponse
                }else {
                    manualRelationCalcResponse.content = ArrayList()
                    manualRelationCalcResponse.result = SResponseType.success
                }


            }else {
                manualRelationCalcResponse.content = ArrayList()
                manualRelationCalcResponse.result = SResponseType.success
            }

        }
        return  manualRelationCalcResponse

    }

    fun queryEq2Fl(manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {
        val sQueryRequest = SQueryRequest()
        if(manualRelationCalcRequest.pageNumber>0&&manualRelationCalcRequest.pageSize>0){
            SQueryRequest.maxRow = 400000
            sQueryRequest.pageSize= manualRelationCalcRequest.pageSize
            sQueryRequest.pageNumber = manualRelationCalcRequest.pageNumber
        }else{
            /** 控制条数 */
            SQueryRequest.maxRow = 100000
            sQueryRequest.pageSize= 100000
        }

        val sCascadeQueryList = ArrayList<SCascadeQuery>()
        /** 级联资产 */
        val sCascadeQuery = SCascadeQuery()
        sCascadeQuery.name = "objectInfo"
        sCascadeQueryList.add(sCascadeQuery)
        sQueryRequest.cascade = sCascadeQueryList

        val manualRelationCalcResponse = ManualRelationCalcResponse()
        manualRelationCalcResponse.direction = "Left"
        val list = ArrayList<SFilter>()
        list.add(SFilter.eq("projectId",Opt.projectId!!))
        if (manualRelationCalcRequest.objectType == "1") {

            list.add(SFilter.not(SFilter.isNull("floorId")))
            /** 模糊查询 */
            if(!manualRelationCalcRequest.vagueFrom.isNullOrEmpty()){
                list.add( SFilter.or(SFilter.contain("id",manualRelationCalcRequest.vagueFrom!!),SFilter.contain("name",manualRelationCalcRequest.vagueFrom!!)
                        ,SFilter.contain("localName",manualRelationCalcRequest.vagueFrom!!),SFilter.contain("localId",manualRelationCalcRequest.vagueFrom!!)))
            }
            if (!manualRelationCalcRequest.categoryFrom.isNullOrEmpty()) {
                list.add(SFilter.eq("classCode",manualRelationCalcRequest.categoryFrom!!))
            }
            val pageQuery = relEquipFloorService.pageQuery(sQueryRequest,list)
            manualRelationCalcResponse.content = pageQuery.content
            manualRelationCalcResponse.message = pageQuery.message
            manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
            manualRelationCalcResponse.pageSize = pageQuery.pageSize
            manualRelationCalcResponse.result = pageQuery.result
            manualRelationCalcResponse.total = pageQuery.total

            return manualRelationCalcResponse
        }else if (manualRelationCalcRequest.objectType == "2"){

            if (!manualRelationCalcRequest.vagueFrom.isNullOrEmpty()) {
                val relEquipBuildingList = relEquipFloorService.select(SFilter.eq("projectId", Opt.projectId!!), SFilter.not(SFilter.isNull("floorId"))).exec()
                if (relEquipBuildingList.size>0) {

                    val buildingIdList = schemeMapper.floorId(Opt.projectId!!)
                    val listId = ArrayList<String>()
                    for (buildingId in buildingIdList) {
                        listId.add(buildingId.id!!)
                    }

                    val relBuildinglist = relFloorService.select(SFilter.inList("id", listId), SFilter.contain("localName", manualRelationCalcRequest.vagueTo!!)).exec()
                    if (relBuildinglist.size>0) {
                        val listIds = ArrayList<String>()
                        for (building in relBuildinglist) {
                            listIds.add(building.id!!)
                        }
                        list.add(SFilter.inList("floorId",listIds))
                        val pageQuery = relEquipFloorService.pageQuery(sQueryRequest,list)
                        manualRelationCalcResponse.content = pageQuery.content
                        manualRelationCalcResponse.message = pageQuery.message
                        manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                        manualRelationCalcResponse.pageSize = pageQuery.pageSize
                        manualRelationCalcResponse.result = pageQuery.result
                        manualRelationCalcResponse.total = pageQuery.total

                        return manualRelationCalcResponse
                    }else {
                        manualRelationCalcResponse.content = ArrayList()
                        manualRelationCalcResponse.result = SResponseType.success
                    }
                }else {
                    manualRelationCalcResponse.content = ArrayList()
                    manualRelationCalcResponse.result = SResponseType.success
                }
            }else {
                manualRelationCalcResponse.content = ArrayList()
                manualRelationCalcResponse.result = SResponseType.success
            }

        }else if (manualRelationCalcRequest.objectType == "3") {

            val listType = ArrayList<SFilter>()
            /** 模糊查询 */
            if(!manualRelationCalcRequest.vagueFrom.isNullOrEmpty()){
                listType.add( SFilter.or(SFilter.contain("id",manualRelationCalcRequest.vagueFrom!!),SFilter.contain("name",manualRelationCalcRequest.vagueFrom!!)
                        ,SFilter.contain("localName",manualRelationCalcRequest.vagueFrom!!),SFilter.contain("localId",manualRelationCalcRequest.vagueFrom!!)))
            }
            if (!manualRelationCalcRequest.categoryFrom.isNullOrEmpty()) {
                listType.add(SFilter.eq("classCode",manualRelationCalcRequest.categoryFrom!!))
            }
            listType.add(SFilter.not(SFilter.isNull("floorId")))
            val relEquipBuildingList = relEquipFloorService.select(listType).exec()
            if (relEquipBuildingList.size>0) {

                val relBuildinglist = relFloorService.select(SFilter.eq("projectId", Opt.projectId!!), SFilter.contain("localName", manualRelationCalcRequest.vagueTo!!)).exec()
                if (relBuildinglist.size>0) {
                    val listIds = ArrayList<String>()
                    for (building in relBuildinglist) {
                        listIds.add(building.id!!)
                    }
                    val listEquipIds = ArrayList<String>()
                    for (relEquipBuilding in relEquipBuildingList) {
                        listEquipIds.add(relEquipBuilding.id!!)
                    }

                    list.add(SFilter.inList("floorId",listIds))
                    list.add(SFilter.inList("id",listEquipIds))
                    val pageQuery = relEquipFloorService.pageQuery(sQueryRequest,list)
                    manualRelationCalcResponse.content = pageQuery.content
                    manualRelationCalcResponse.message = pageQuery.message
                    manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                    manualRelationCalcResponse.pageSize = pageQuery.pageSize
                    manualRelationCalcResponse.result = pageQuery.result
                    manualRelationCalcResponse.total = pageQuery.total
                    return manualRelationCalcResponse
                }else {
                    manualRelationCalcResponse.content = ArrayList()
                    manualRelationCalcResponse.result = SResponseType.success
                }


            }else {
                manualRelationCalcResponse.content = ArrayList()
                manualRelationCalcResponse.result = SResponseType.success
            }

        }
        return  manualRelationCalcResponse
    }

    /**
     * 建筑下的空间
     */
    fun queryBd2Sp(manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse{
        val sQueryRequest = SQueryRequest()
        if(manualRelationCalcRequest.pageNumber>0&&manualRelationCalcRequest.pageSize>0){
            SQueryRequest.maxRow = 400000
            sQueryRequest.pageSize= manualRelationCalcRequest.pageSize
            sQueryRequest.pageNumber = manualRelationCalcRequest.pageNumber
        }else{
            /** 控制条数 */
            SQueryRequest.maxRow = 100000
            sQueryRequest.pageSize= 100000
        }

        val sCascadeQueryList = ArrayList<SCascadeQuery>()
        /** 级联资产 */
        val sCascadeQuery = SCascadeQuery()
        sCascadeQuery.name = "objectInfo"
        sCascadeQueryList.add(sCascadeQuery)
        sQueryRequest.cascade = sCascadeQueryList

        val manualRelationCalcResponse = ManualRelationCalcResponse()
        manualRelationCalcResponse.direction = "Left"
        val list = ArrayList<SFilter>()
        list.add(SFilter.eq("projectId",Opt.projectId!!))
        if (manualRelationCalcRequest.objectType == "1") {
           if (!manualRelationCalcRequest.vagueFrom.isNullOrEmpty()) {
               list.add(SFilter.contain("localName",manualRelationCalcRequest.vagueFrom!!))
           }
            val pageQuery = rBd2SpBuilidingService.pageQuery(sQueryRequest, list)
            manualRelationCalcResponse.content = pageQuery.content
            manualRelationCalcResponse.message = pageQuery.message
            manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
            manualRelationCalcResponse.pageSize = pageQuery.pageSize
            manualRelationCalcResponse.result = pageQuery.result
            manualRelationCalcResponse.total = pageQuery.total
            return manualRelationCalcResponse

        }else if (manualRelationCalcRequest.objectType == "2"){
            val listSpace = ArrayList<SFilter>()
            listSpace.add(SFilter.eq("projectId",Opt.projectId!!))
            /** 筛选空间 */
            if (!manualRelationCalcRequest.zoneType.isNullOrEmpty()) {
                listSpace.add(SFilter.eq("classCode",manualRelationCalcRequest.zoneType!!))
            }
            if (!manualRelationCalcRequest.vagueTo.isNullOrEmpty()) {
                listSpace.add(SFilter.or(SFilter.contain("localName",manualRelationCalcRequest.vagueTo!!),SFilter.contain("localId",manualRelationCalcRequest.vagueTo!!)))
            }
            val spaceBaseList = spaceBaseZoneService.select(listSpace).exec()
            if (spaceBaseList.size>0) {



            }else {
                manualRelationCalcResponse.content = ArrayList()
                manualRelationCalcResponse.result = SResponseType.success
            }

            return manualRelationCalcResponse

        }else if (manualRelationCalcRequest.objectType == "3") {
            return manualRelationCalcResponse
        }
        return manualRelationCalcResponse
    }




    /**
     * 删除关系
     */
    fun delRel(manualRelationCalcDel: ManualRelationCalcDel):SBaseResponse{
        try {
            val projectId = SPageContext.getHeader("projectId")

            var delete: Boolean = false
            if(!manualRelationCalcDel.fromId.isNullOrEmpty()&&manualRelationCalcDel.toId.isNullOrEmpty()){

                try {
                    val relationTypeProjectService = SObjectService(SMybatisDao(RelationTypeProject::class.java))

                    val relationType = relationTypeProjectService.select(SFilter.eq("projectId", projectId!!),SFilter.eq("graphicType", manualRelationCalcDel.graphicType!!)
                            ,SFilter.eq("relationType", manualRelationCalcDel.relType!!)).entity()
                    if (relationType!=null){
                        relationType.computingTime = time()
                        relationTypeProjectService.update(relationType)
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }

                if (manualRelationCalcDel.graphicType == "ArchSubset" && manualRelationCalcDel.relType == "Bd2Sp") {
                    val relZoneSpace = RelZoneSpace()
                    relZoneSpace.id = manualRelationCalcDel.fromId
                    delete = relZoneSpaceService.update(relZoneSpace, arrayListOf("buildingId", "floorId"))
                } else if (manualRelationCalcDel.graphicType == "ArchSubset" && manualRelationCalcDel.relType == "Fl2Sp") {
                    val relZoneSpace = RelZoneSpace()
                    relZoneSpace.id = manualRelationCalcDel.fromId
                    delete = relZoneSpaceService.update(relZoneSpace, arrayListOf( "floorId"))
                } else if (manualRelationCalcDel.graphicType == "MechInArch" && manualRelationCalcDel.relType == "Eq2Bd") {
                    val equipment = Equipment()
                    equipment.id = manualRelationCalcDel.fromId
                    delete = EquipmentService.update(equipment, arrayListOf("buildingId", "floorId"))
                } else if (manualRelationCalcDel.graphicType == "MechInArch" && manualRelationCalcDel.relType == "Eq2Fl") {
                    val equipment = Equipment()
                    equipment.id = manualRelationCalcDel.fromId
                    delete = EquipmentService.update(equipment, arrayListOf("floorId"))
                } else if (manualRelationCalcDel.graphicType == "ArchForArch" && manualRelationCalcDel.relType == "Sp2Sp") {
                    delete = rSp2SpService.delete(SFilter.eq("id1",manualRelationCalcDel.fromId!!),SFilter.eq("id2",manualRelationCalcDel.toId!!),
                            SFilter.eq("graphCode",manualRelationCalcDel.graphicType!!),SFilter.eq("type",manualRelationCalcDel.relType!!))
                } else if (manualRelationCalcDel.graphicType == "MechSubset" && manualRelationCalcDel.relType == "Sy2Eq") {
                    delete = rSp2SpService.delete(SFilter.eq("id1",manualRelationCalcDel.fromId!!),SFilter.eq("id2",manualRelationCalcDel.toId!!),
                            SFilter.eq("graphCode",manualRelationCalcDel.graphicType!!),SFilter.eq("type",manualRelationCalcDel.relType!!))
                } else if (manualRelationCalcDel.graphicType == "MechInArch" && manualRelationCalcDel.relType == "Eq2Sp") {
                    delete = rSp2SpService.delete(SFilter.eq("id1",manualRelationCalcDel.fromId!!),SFilter.eq("id2",manualRelationCalcDel.toId!!),
                            SFilter.eq("graphCode",manualRelationCalcDel.graphicType!!),SFilter.eq("type",manualRelationCalcDel.relType!!))
                } else if (manualRelationCalcDel.graphicType == "MechForArch" && manualRelationCalcDel.relType == "Eq2Sp") {
                    delete = rSp2SpService.delete(SFilter.eq("id1",manualRelationCalcDel.fromId!!),SFilter.eq("id2",manualRelationCalcDel.toId!!),
                            SFilter.eq("graphCode",manualRelationCalcDel.graphicType!!),SFilter.eq("type",manualRelationCalcDel.relType!!))
                }
                if (delete){
                    /** 发送消息 */
                    rabbitMqService.sendRel(Opt.projectId!!, manualRelationCalcDel.relType!!,"15",manualRelationCalcDel.fromId!!,"123456")
                    return SBaseResponse(SResponseType.success)
                }else{
                    return  SBaseResponse(SResponseType.failure)
                }
            }else{
                /** 主对象和从对象都不可以为空 */
                return  SBaseResponse(SResponseType.failure)
            }
        } catch (e: Exception) {
            e.printStackTrace()
            return  SBaseResponse(SResponseType.failure,e.message.toString())
        }
    }

    /**
     * 空间和建筑的关系
     */
    fun queryBd2Sp(projectId: String,list: ArrayList<SFilter>,sQueryRequest: SQueryRequest,manualRelationCalcRequest: ManualRelationCalcRequest) {

    }


    /**
     * 设备设施服务于竖井 eq2sh_for
     */
    fun queryEqForSh(projectId: String,list: ArrayList<SFilter>,sQueryRequest: SQueryRequest,manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {
        /** 设备服务于竖井 */
        val rEqForShList = REqInShService.select(SFilter.eq("projectId", projectId)).exec()
        if (rEqForShList.size>0){

            if (manualRelationCalcRequest.objectType == "1"){

                val listId = ArrayList<String>()
                for (rPeInSp in rEqForShList){
                    listId.add(rPeInSp.equipId!!)
                }
                list.add(SFilter.inList("id",listId))
                val pageQuery = relEquipmentShaftService.pageQuery(sQueryRequest, list)
                val manualRelationCalcResponse = ManualRelationCalcResponse()
                manualRelationCalcResponse.direction = "Left"
                manualRelationCalcResponse.content = pageQuery.content
                manualRelationCalcResponse.message = pageQuery.message
                manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                manualRelationCalcResponse.pageSize = pageQuery.pageSize
                manualRelationCalcResponse.result = pageQuery.result
                manualRelationCalcResponse.total = pageQuery.total
                logger.debug("条件1= ${manualRelationCalcResponse.toJson()}")
                return manualRelationCalcResponse

            }else if (manualRelationCalcRequest.objectType == "2"){
                val listId = ArrayList<String>()
                for (rPeInSh in rEqForShList){
                    listId.add(rPeInSh.shaftId!!)
                }
                list.add(SFilter.inList("id",listId))
                /** 竖井 */
                val relShaftList = relShaftService.select(list).exec()

                if (relShaftList.size>0){
                    val listIdShaft = ArrayList<String>()
                    for (relShaft in relShaftList){
                        listIdShaft.add(relShaft.id!!)
                    }
                    /** 设备服务的竖井 */
                    val rPeInShaftList = REqInShService.select(SFilter.eq("projectId", projectId!!), SFilter.inList("shaftId", listIdShaft)).exec()
                    listIdShaft.clear()
                    for (rPeInShaftin in rPeInShaftList){
                        listIdShaft.add(rPeInShaftin.equipId!!)
                    }
                    val listSFilter = ArrayList<SFilter>()
                    listSFilter.add(SFilter.eq("projectId",projectId))
                    listSFilter.add(SFilter.inList("id",listIdShaft))
                    /** 设备 */
                    val pageQuery = relEquipmentShaftService.pageQuery(sQueryRequest, listSFilter)

                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.direction = "Left"
                    manualRelationCalcResponse.content = pageQuery.content
                    manualRelationCalcResponse.message = pageQuery.message
                    manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                    manualRelationCalcResponse.pageSize = pageQuery.pageSize
                    manualRelationCalcResponse.result = pageQuery.result
                    manualRelationCalcResponse.total = pageQuery.total
                    return manualRelationCalcResponse
                }else{
                    /** 暂无数据 */
                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.result = SResponseType.success
//                    manualRelationCalcResponse.content = ArrayList<RelProperty>()
                    return manualRelationCalcResponse
                }
            }
        }
        /** 暂无数据 */
        val manualRelationCalcResponse = ManualRelationCalcResponse()
        manualRelationCalcResponse.result = SResponseType.success
//        manualRelationCalcResponse.content = ArrayList<RelProperty>()
        return manualRelationCalcResponse
    } // Fun

    /**
     * 设备服务于楼层 eq2fl_for
     */
    fun queryEqForFl(projectId: String,list: ArrayList<SFilter>,sQueryRequest: SQueryRequest,manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {
        val rEqForFlList = REqForFlService.select(SFilter.eq("projectId", projectId)).exec()
        if (rEqForFlList.size>0){

            if (manualRelationCalcRequest.objectType == "1"){
                val listId = ArrayList<String>()
                for (rPeInSp in rEqForFlList){
                    listId.add(rPeInSp.equipId!!)
                }
                list.add(SFilter.inList("id",listId))

                val pageQuery = relEquipmentFloorService.pageQuery(sQueryRequest, list)
                val manualRelationCalcResponse = ManualRelationCalcResponse()
                manualRelationCalcResponse.direction = "Left"
                manualRelationCalcResponse.content = pageQuery.content
                manualRelationCalcResponse.message = pageQuery.message
                manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                manualRelationCalcResponse.pageSize = pageQuery.pageSize
                manualRelationCalcResponse.result = pageQuery.result
                manualRelationCalcResponse.total = pageQuery.total
                logger.debug("条件1= ${manualRelationCalcResponse.toJson()}")
                return manualRelationCalcResponse
            }else if (manualRelationCalcRequest.objectType == "2"){
                val listId = ArrayList<String>()
                for (rPeInSh in rEqForFlList){
                    listId.add(rPeInSh.floorId!!)
                }
                list.add(SFilter.inList("id",listId))
                val floorList = FloorService.select(list).exec()
                if (floorList.size>0){
                    val listFloorId = ArrayList<String>()
                    for (relShaft in floorList){
                        listFloorId.add(relShaft.id!!)
                    }

                    val rEqForFlList = REqForFlService.select(SFilter.eq("projectId", projectId!!), SFilter.inList("floorId", listFloorId)).exec()

                    listFloorId.clear()
                    for (rPeInShaftin in rEqForFlList){
                        listFloorId.add(rPeInShaftin.equipId!!)
                    }
                    val listSFilter = ArrayList<SFilter>()
                    listSFilter.add(SFilter.eq("projectId",projectId))
                    listSFilter.add(SFilter.inList("id",listFloorId))
                    /** 设备 */
                    val pageQuery = relEquipmentFloorService.pageQuery(sQueryRequest, listSFilter)
                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.direction = "Left"
                    manualRelationCalcResponse.content = pageQuery.content
                    manualRelationCalcResponse.message = pageQuery.message
                    manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                    manualRelationCalcResponse.pageSize = pageQuery.pageSize
                    manualRelationCalcResponse.result = pageQuery.result
                    manualRelationCalcResponse.total = pageQuery.total
                    return manualRelationCalcResponse
                }else{
                    /** 暂无数据 */
                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.result = SResponseType.success
//                    manualRelationCalcResponse.content = ArrayList<RelProperty>()
                    return manualRelationCalcResponse
                }
            }

        }
        /** 暂无数据 */
        val manualRelationCalcResponse = ManualRelationCalcResponse()
        manualRelationCalcResponse.result = SResponseType.success
//        manualRelationCalcResponse.content = ArrayList<RelProperty>()
        return manualRelationCalcResponse

    }  // Fun

    /**
     * 设备服务于建筑  eq2bd_for
     */
    fun queryEqForBd(projectId: String,list: ArrayList<SFilter>,sQueryRequest: SQueryRequest,manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {
        val rEqForBdList = REqForBdService.select(SFilter.eq("projectId", projectId)).exec()
        if (rEqForBdList.size>0){
            if (manualRelationCalcRequest.objectType == "1"){
                val listId = ArrayList<String>()
                for (rEqForBd in rEqForBdList){
                    listId.add(rEqForBd.equipId!!)
                }
                list.add(SFilter.inList("id",listId))
                val pageQuery = relEquipmentBuildingService.pageQuery(sQueryRequest, list)
                val manualRelationCalcResponse = ManualRelationCalcResponse()
                manualRelationCalcResponse.direction = "Left"
                manualRelationCalcResponse.content = pageQuery.content
                manualRelationCalcResponse.message = pageQuery.message
                manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                manualRelationCalcResponse.pageSize = pageQuery.pageSize
                manualRelationCalcResponse.result = pageQuery.result
                manualRelationCalcResponse.total = pageQuery.total
                logger.debug("条件1= ${manualRelationCalcResponse.toJson()}")
                return manualRelationCalcResponse

            }else if (manualRelationCalcRequest.objectType == "2"){
                val listId = ArrayList<String>()
                for (rEqForBd in rEqForBdList){
                    listId.add(rEqForBd.buildingId!!)
                }
                list.add(SFilter.inList("id",listId))
                val buildingList = BuildingService.select(list).exec()
                if (buildingList.size>0){
                    val listBuildingId = ArrayList<String>()
                    for (building in buildingList){
                        listBuildingId.add(building.id!!)
                    }

                    val rEqForBdLists = REqForBdService.select(SFilter.eq("projectId", projectId), SFilter.inList("buildingId", listBuildingId)).exec()
                    listBuildingId.clear()
                    for (rEqForBd in rEqForBdLists){
                        listBuildingId.add(rEqForBd.equipId!!)
                    }
                    val listSFilter = ArrayList<SFilter>()
                    listSFilter.add(SFilter.eq("projectId",projectId))
                    listSFilter.add(SFilter.inList("id",listBuildingId))
                    /** 设备 */
                    val pageQuery = relEquipmentBuildingService.pageQuery(sQueryRequest, listSFilter)
                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.direction = "Left"
                    manualRelationCalcResponse.content = pageQuery.content
                    manualRelationCalcResponse.message = pageQuery.message
                    manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                    manualRelationCalcResponse.pageSize = pageQuery.pageSize
                    manualRelationCalcResponse.result = pageQuery.result
                    manualRelationCalcResponse.total = pageQuery.total
                    return manualRelationCalcResponse
                }else{
                    /** 暂无数据 */
                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.result = SResponseType.success
//                    manualRelationCalcResponse.content = ArrayList<RelProperty>()
                    return manualRelationCalcResponse
                }
            }
            /** 暂无数据 */
            val manualRelationCalcResponse = ManualRelationCalcResponse()
            manualRelationCalcResponse.result = SResponseType.success
//            manualRelationCalcResponse.content = ArrayList<RelProperty>()
            return manualRelationCalcResponse
        }
        /** 暂无数据 */
        val manualRelationCalcResponse = ManualRelationCalcResponse()
        manualRelationCalcResponse.result = SResponseType.success
//        manualRelationCalcResponse.content = ArrayList<RelProperty>()
        return manualRelationCalcResponse
    } // Fun

    /**
     * 系统服务于业务空间  sy2sp_for
     */
    fun querySyForSp(projectId: String,list: ArrayList<SFilter>,sQueryRequest: SQueryRequest,manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {
        val rSyForSpBaseList = rSy2SpService.select(SFilter.eq("projectId", projectId),SFilter.eq("type", "sy2sp_for")).exec()
        if (rSyForSpBaseList.size>0){
            if (manualRelationCalcRequest.objectType == "1"){
                val listId = ArrayList<String>()
                for (rSyForSp in rSyForSpBaseList){
                    listId.add(rSyForSp.id1!!)
                }
                list.add(SFilter.inList("id",listId))
                val pageQuery = relGeneralSystemService.pageQuery(sQueryRequest, list)
                val manualRelationCalcResponse = ManualRelationCalcResponse()
                manualRelationCalcResponse.direction = "Left"
                manualRelationCalcResponse.content = pageQuery.content
                manualRelationCalcResponse.message = pageQuery.message
                manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                manualRelationCalcResponse.pageSize = pageQuery.pageSize
                manualRelationCalcResponse.result = pageQuery.result
                manualRelationCalcResponse.total = pageQuery.total
                logger.debug("条件1= ${manualRelationCalcResponse.toJson()}")
                return manualRelationCalcResponse
            }else if (manualRelationCalcRequest.objectType == "2"){
                val listId = ArrayList<String>()
                for (rSyForSp in rSyForSpBaseList){
                    listId.add(rSyForSp.id2!!)
                }
                list.add(SFilter.inList("id",listId))

                val relZoneSpaceLists = relZoneSpaceService.select(list).exec()
                if (relZoneSpaceLists.size>0){
                    val listIds = ArrayList<String>()
                    for (relZoneSpace in relZoneSpaceLists){
                        listIds.add(relZoneSpace.id!!)
                    }

                    val rSyForSpBaseLists = rSy2SpService.select(SFilter.eq("projectId", projectId!!), SFilter.inList("id2", listIds),SFilter.eq("type", "sy2sp_for")).exec()
                    listIds.clear()
                    for (rSyForSp in rSyForSpBaseLists){
                        listIds.add(rSyForSp.id1!!)
                    }
                    val listSFilter = ArrayList<SFilter>()
                    listSFilter.add(SFilter.eq("projectId",projectId))
                    listSFilter.add(SFilter.inList("id",listIds))
                    val pageQuery = relGeneralSystemService.pageQuery(sQueryRequest, listSFilter)
                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.direction = "Left"
                    manualRelationCalcResponse.content = pageQuery.content
                    manualRelationCalcResponse.message = pageQuery.message
                    manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                    manualRelationCalcResponse.pageSize = pageQuery.pageSize
                    manualRelationCalcResponse.result = pageQuery.result
                    manualRelationCalcResponse.total = pageQuery.total
                    return manualRelationCalcResponse
                }else{
                    /** 暂无数据 */
                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.result = SResponseType.success
//                    manualRelationCalcResponse.content = ArrayList<RelProperty>()
                    return manualRelationCalcResponse
                }
            }
        }
        /** 暂无数据 */
        val manualRelationCalcResponse = ManualRelationCalcResponse()
        manualRelationCalcResponse.result = SResponseType.success
//        manualRelationCalcResponse.content = ArrayList<RelProperty>()
        return manualRelationCalcResponse
    } // Fun

    /**
     * 系统服务于竖井 sy2sh_for
     */
    fun querySyForSh(projectId: String,list: ArrayList<SFilter>,sQueryRequest: SQueryRequest,manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {

        val rSyForShList = RSyForShService.select(SFilter.eq("projectId", projectId)).exec()
        if (rSyForShList.size>0) {
            if (manualRelationCalcRequest.objectType == "1") {
                val listId = ArrayList<String>()
                for (rSyForSh in rSyForShList) {
                    listId.add(rSyForSh.sysId!!)
                }
                list.add(SFilter.inList("id", listId))
                val pageQuery = relGeneralSystemShaftService.pageQuery(sQueryRequest, list)
                val manualRelationCalcResponse = ManualRelationCalcResponse()
                manualRelationCalcResponse.direction = "Left"
                manualRelationCalcResponse.content = pageQuery.content
                manualRelationCalcResponse.message = pageQuery.message
                manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                manualRelationCalcResponse.pageSize = pageQuery.pageSize
                manualRelationCalcResponse.result = pageQuery.result
                manualRelationCalcResponse.total = pageQuery.total
                logger.debug("条件1= ${manualRelationCalcResponse.toJson()}")
                return manualRelationCalcResponse

            } else if (manualRelationCalcRequest.objectType == "2") {
                val listId = ArrayList<String>()
                for (rSyForSh in rSyForShList) {
                    listId.add(rSyForSh.shaftId!!)
                }
                list.add(SFilter.inList("id", listId))
                /** 竖井 */
                val relShaftList = relShaftService.select(list).exec()

                if (relShaftList.size > 0) {
                    val listIdShaft = ArrayList<String>()
                    for (relShaft in relShaftList) {
                        listIdShaft.add(relShaft.id!!)
                    }
                    /** 系统服务的竖井 */
                    val rSyForShList = RSyForShService.select(SFilter.eq("projectId", projectId!!), SFilter.inList("shaftId", listIdShaft)).exec()
                    listIdShaft.clear()
                    for (rSyForSh in rSyForShList) {
                        listIdShaft.add(rSyForSh.sysId!!)
                    }
                    val listSFilter = ArrayList<SFilter>()
                    listSFilter.add(SFilter.eq("projectId", projectId))
                    listSFilter.add(SFilter.inList("id", listIdShaft))
                    /** 系统 */
                    val pageQuery = relGeneralSystemShaftService.pageQuery(sQueryRequest, listSFilter)

                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.direction = "Left"
                    manualRelationCalcResponse.content = pageQuery.content
                    manualRelationCalcResponse.message = pageQuery.message
                    manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                    manualRelationCalcResponse.pageSize = pageQuery.pageSize
                    manualRelationCalcResponse.result = pageQuery.result
                    manualRelationCalcResponse.total = pageQuery.total
                    return manualRelationCalcResponse
                }
                /** 暂无数据 */
                val manualRelationCalcResponse = ManualRelationCalcResponse()
                manualRelationCalcResponse.result = SResponseType.success
//                manualRelationCalcResponse.content = ArrayList<RelProperty>()
                return manualRelationCalcResponse
            }
            /** 暂无数据 */
            val manualRelationCalcResponse = ManualRelationCalcResponse()
            manualRelationCalcResponse.result = SResponseType.success
//            manualRelationCalcResponse.content = ArrayList<RelProperty>()
            return manualRelationCalcResponse
        }
        /** 暂无数据 */
        val manualRelationCalcResponse = ManualRelationCalcResponse()
        manualRelationCalcResponse.result = SResponseType.success
//        manualRelationCalcResponse.content = ArrayList<RelProperty>()
        return manualRelationCalcResponse
    } // Fun

    /**
     * 系统服务于楼层  sy2fl_for
     */
    fun querySyForFl(projectId: String,list: ArrayList<SFilter>,sQueryRequest: SQueryRequest,manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {
        val rSyForFlList = RSyForFlService.select(SFilter.eq("projectId", projectId)).exec()
        if (rSyForFlList.size>0){
            if (manualRelationCalcRequest.objectType == "1") {
                val listId = ArrayList<String>()
                for (rSyForFl in rSyForFlList) {
                    listId.add(rSyForFl.sysId!!)
                }
                list.add(SFilter.inList("id", listId))
                val pageQuery = relGeneralSystemFloorService.pageQuery(sQueryRequest, list)
                val manualRelationCalcResponse = ManualRelationCalcResponse()
                manualRelationCalcResponse.direction = "Left"
                manualRelationCalcResponse.content = pageQuery.content
                manualRelationCalcResponse.message = pageQuery.message
                manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                manualRelationCalcResponse.pageSize = pageQuery.pageSize
                manualRelationCalcResponse.result = pageQuery.result
                manualRelationCalcResponse.total = pageQuery.total
                logger.debug("条件1= ${manualRelationCalcResponse.toJson()}")
                return manualRelationCalcResponse
            }else if (manualRelationCalcRequest.objectType == "2") {
                val listId = ArrayList<String>()
                for (rSyForFl in rSyForFlList) {
                    listId.add(rSyForFl.floorId!!)
                }
                list.add(SFilter.inList("id", listId))
                /** 楼层 */
                val floorList = FloorService.select(list).exec()
                if (floorList.size > 0) {
                    val listFloorId = ArrayList<String>()
                    for (relFloor in floorList) {
                        listFloorId.add(relFloor.id!!)
                    }

                    val rSyForFlList = RSyForFlService.select(SFilter.eq("projectId", projectId!!), SFilter.inList("floorId", listFloorId)).exec()

                    listFloorId.clear()
                    for (rSyForFl in rSyForFlList) {
                        listFloorId.add(rSyForFl.sysId!!)
                    }
                    val listSFilter = ArrayList<SFilter>()
                    listSFilter.add(SFilter.eq("projectId", projectId))
                    listSFilter.add(SFilter.inList("id", listFloorId))
                    /** 系统 */
                    val pageQuery = relGeneralSystemFloorService.pageQuery(sQueryRequest, listSFilter)
                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.direction = "Left"
                    manualRelationCalcResponse.content = pageQuery.content
                    manualRelationCalcResponse.message = pageQuery.message
                    manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                    manualRelationCalcResponse.pageSize = pageQuery.pageSize
                    manualRelationCalcResponse.result = pageQuery.result
                    manualRelationCalcResponse.total = pageQuery.total
                    return manualRelationCalcResponse
                }
            }
            /** 暂无数据 */
            val manualRelationCalcResponse = ManualRelationCalcResponse()
            manualRelationCalcResponse.result = SResponseType.success
//            manualRelationCalcResponse.content = ArrayList<RelProperty>()
            return manualRelationCalcResponse
        }
        /** 暂无数据 */
        val manualRelationCalcResponse = ManualRelationCalcResponse()
        manualRelationCalcResponse.result = SResponseType.success
//        manualRelationCalcResponse.content = ArrayList<RelProperty>()
        return manualRelationCalcResponse
    } // Fun

    /**
     * 系统服务于建筑 sy2bd_for
     */
    fun querySyForBd(projectId: String,list: ArrayList<SFilter>,sQueryRequest: SQueryRequest,manualRelationCalcRequest: ManualRelationCalcRequest): ManualRelationCalcResponse {
        val rSyForBdList = RSyForBdService.select(SFilter.eq("projectId", projectId)).exec()
        if (rSyForBdList.size>0){
            if (manualRelationCalcRequest.objectType == "1") {
                val listId = ArrayList<String>()
                for (rSyForBd in rSyForBdList) {
                    listId.add(rSyForBd.sysId!!)
                }
                list.add(SFilter.inList("id", listId))
                val pageQuery = relGeneralSystemBuildingService.pageQuery(sQueryRequest, list)
                val manualRelationCalcResponse = ManualRelationCalcResponse()
                manualRelationCalcResponse.direction = "Left"
                manualRelationCalcResponse.content = pageQuery.content
                manualRelationCalcResponse.message = pageQuery.message
                manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                manualRelationCalcResponse.pageSize = pageQuery.pageSize
                manualRelationCalcResponse.result = pageQuery.result
                manualRelationCalcResponse.total = pageQuery.total
                logger.debug("条件1= ${manualRelationCalcResponse.toJson()}")
                return manualRelationCalcResponse
            }else if (manualRelationCalcRequest.objectType == "2"){
                val listId = ArrayList<String>()
                for (rSyForBd in rSyForBdList){
                    listId.add(rSyForBd.buildingId!!)
                }
                list.add(SFilter.inList("id",listId))
                val buildingList = BuildingService.select(list).exec()
                if (buildingList.size>0){
                    val listBuildingId = ArrayList<String>()
                    for (building in buildingList){
                        listBuildingId.add(building.id!!)
                    }
                    val rSyForBdLists = RSyForBdService.select(SFilter.eq("projectId", projectId), SFilter.inList("buildingId", listBuildingId)).exec()
                    listBuildingId.clear()
                    for (rSyForBd in rSyForBdLists){
                        listBuildingId.add(rSyForBd.sysId!!)
                    }
                    val listSFilter = ArrayList<SFilter>()
                    listSFilter.add(SFilter.eq("projectId",projectId))
                    listSFilter.add(SFilter.inList("id",listBuildingId))
                    /** 设备 */
                    val pageQuery = relGeneralSystemBuildingService.pageQuery(sQueryRequest, listSFilter)
                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.direction = "Left"
                    manualRelationCalcResponse.content = pageQuery.content
                    manualRelationCalcResponse.message = pageQuery.message
                    manualRelationCalcResponse.pageNumber = pageQuery.pageNumber
                    manualRelationCalcResponse.pageSize = pageQuery.pageSize
                    manualRelationCalcResponse.result = pageQuery.result
                    manualRelationCalcResponse.total = pageQuery.total
                    return manualRelationCalcResponse
                }else{
                    /** 暂无数据 */
                    val manualRelationCalcResponse = ManualRelationCalcResponse()
                    manualRelationCalcResponse.result = SResponseType.success
//                    manualRelationCalcResponse.content = ArrayList<RelProperty>()
                    return manualRelationCalcResponse
                }
            }
        }
        /** 暂无数据 */
        val manualRelationCalcResponse = ManualRelationCalcResponse()
        manualRelationCalcResponse.result = SResponseType.success
//        manualRelationCalcResponse.content = ArrayList<RelProperty>()
        return manualRelationCalcResponse
    }





    fun time():String {
        val df = SimpleDateFormat("yyyy-MM-dd HH:mm:ss") //设置日期格式
        println(df.format(Date())) // new Date()为获取当前系统时间
        return df.format(Date())
    } // Fun


}